@@ -16,16 +16,18 @@
 extern "C" {
 #endif // __cplusplus
 
+#include <stdbool.h>
 #include <stdint.h>
 #include "EbSvtAv1Formats.h"
+#include "EbConfigMacros.h"
 #include "EbDebugMacros.h"
 
 struct SvtMetadataArray;
 
 // API Version
-#define SVT_AV1_VERSION_MAJOR 2
-#define SVT_AV1_VERSION_MINOR 3
-#define SVT_AV1_VERSION_PATCHLEVEL 0
+#define SVT_AV1_VERSION_MAJOR 3
+#define SVT_AV1_VERSION_MINOR 1
+#define SVT_AV1_VERSION_PATCHLEVEL 2
 
 #define SVT_AV1_CHECK_VERSION(major, minor, patch)                                                               \
     (SVT_AV1_VERSION_MAJOR > (major) || (SVT_AV1_VERSION_MAJOR == (major) && SVT_AV1_VERSION_MINOR > (minor)) || \
@@ -75,14 +77,6 @@ typedef enum EbAv1PictureType {
     EB_AV1_INVALID_PICTURE       = 0xFF
 } EbAv1PictureType;
 
-/** The Bool type is intended to be used to represent a true or a false
-value when passing parameters to and from the eBrisk API.  The
-Bool is an 8 bit quantity.
-*/
-typedef uint8_t Bool;
-#define FALSE 0
-#define TRUE 1
-
 typedef struct EbBufferHeaderType {
     // EbBufferHeaderType size
     uint32_t size;
@@ -102,7 +96,9 @@ typedef struct EbBufferHeaderType {
     int64_t  pts;
 
     // pic info
+    uint8_t          temporal_layer_index;
     uint32_t         qp;
+    uint32_t         avg_qp;
     EbAv1PictureType pic_type;
     uint64_t         luma_sse;
     uint64_t         cr_sse;
@@ -157,27 +153,9 @@ typedef struct EbSvtIOFormat //former EbSvtEncInput
     uint8_t *luma;
     uint8_t *cb;
     uint8_t *cr;
-
-    // Hosts LSB 2 bits of 10bit input/output when the compressed 10bit format is used
-#if !SVT_AV1_CHECK_VERSION(1, 5, 0)
-    /* DEPRECATED: to be removed in 1.5.0. */
-    void *luma_ext;
-    void *cb_ext;
-    void *cr_ext;
-#endif
-
     uint32_t y_stride;
     uint32_t cr_stride;
     uint32_t cb_stride;
-
-    uint32_t width;
-    uint32_t height;
-
-    uint32_t org_x;
-    uint32_t org_y;
-
-    EbColorFormat color_fmt;
-    EbBitDepth    bit_depth;
 } EbSvtIOFormat;
 
 typedef struct EbOperatingParametersInfo {
@@ -222,20 +200,12 @@ typedef struct EbColorConfig {
 
     /*!< 1: Indicates that the video does not contain U and V color planes.
      *   0: Indicates that the video contains Y, U, and V color planes. */
-    Bool mono_chrome;
-
+    bool mono_chrome;
     /*!< Specify the chroma subsampling format */
     uint8_t subsampling_x;
 
     /*!< Specify the chroma subsampling format */
     uint8_t subsampling_y;
-
-    /*!< 1: Specifies that color_primaries, transfer_characteristics, and
-            matrix_coefficients are present. color_description_present_flag
-     *   0: Specifies that color_primaries, transfer_characteristics and
-            matrix_coefficients are not present */
-    Bool color_description_present_flag;
-
     /*!< An integer that is defined by the "Color primaries" section of
      * ISO/IEC 23091-4/ITU-T H.273 */
     EbColorPrimaries color_primaries;
@@ -258,13 +228,12 @@ typedef struct EbColorConfig {
     /*!< 1: Indicates that the U and V planes may have separate delta quantizer
      *   0: Indicates that the U and V planes will share the same delta
             quantizer value */
-    Bool separate_uv_delta_q;
-
+    bool separate_uv_delta_q;
 } EbColorConfig;
 
 typedef struct EbTimingInfo {
     /*!< Timing info present flag */
-    Bool timing_info_present;
+    bool timing_info_present;
 
     /*!< Number of time units of a clock operating at the frequency time_scale
      * Hz that corresponds to one increment of a clock tick counter*/
@@ -433,10 +402,15 @@ typedef uint64_t EbCpuFlags;
 #define EB_CPU_FLAGS_AVX512F (1 << 9)
 #define EB_CPU_FLAGS_AVX512CD (1 << 10)
 #define EB_CPU_FLAGS_AVX512DQ (1 << 11)
+#if !SVT_AV1_CHECK_VERSION(4, 0, 0)
+// Deprecated as they were never used.
 #define EB_CPU_FLAGS_AVX512ER (1 << 12)
 #define EB_CPU_FLAGS_AVX512PF (1 << 13)
+#endif
 #define EB_CPU_FLAGS_AVX512BW (1 << 14)
 #define EB_CPU_FLAGS_AVX512VL (1 << 15)
+// AVX512 extensions supported on Icelake and later (Zen 4 and later on AMD)
+#define EB_CPU_FLAGS_AVX512ICL (1 << 16)
 #elif defined(ARCH_AARCH64)
 // Armv8.0-A mandatory Neon instructions.
 #define EB_CPU_FLAGS_NEON (1 << 0)
