@@ -13,10 +13,6 @@
 #include <immintrin.h>
 #include "aom_dsp_rtcd.h"
 
-static INLINE __m128i mm256_add_hi_lo_epi16(const __m256i val) {
-    return _mm_add_epi16(_mm256_castsi256_si128(val), _mm256_extractf128_si256(val, 1));
-}
-
 static INLINE __m128i mm256_add_hi_lo_epi32(const __m256i val) {
     return _mm_add_epi32(_mm256_castsi256_si128(val), _mm256_extractf128_si256(val, 1));
 }
@@ -53,16 +49,12 @@ static INLINE void variance_final_from_32bit_no_sum_avx2(__m256i vsse, uint32_t
     *((int32_t *)sse) = _mm_cvtsi128_si32(res);
 }
 
-// handle pixels (<= 512)
-static INLINE void variance_final_512_no_sum_avx2(__m256i vsse, uint32_t *const sse) {
-    // extract the low lane and add it to the high lane
-    variance_final_from_32bit_no_sum_avx2(vsse, sse);
-}
-
-static INLINE __m256i sum_to_32bit_avx2(const __m256i sum) {
-    const __m256i sum_lo = _mm256_cvtepi16_epi32(_mm256_castsi256_si128(sum));
-    const __m256i sum_hi = _mm256_cvtepi16_epi32(_mm256_extractf128_si256(sum, 1));
-    return _mm256_add_epi32(sum_lo, sum_hi);
+// Horizontal addition for computing the sum in variance calculations.
+// Since the sum is squared at the end (see: Var(X) = E[X^2] - E[X]^2), it doesn't matter that this is negative.
+static INLINE __m256i neg_sum_to_32bit_avx2(const __m256i sum) {
+    // A -1 vector (all bits set) is easier to generate than a 1 vector. Simply cmpeq a register with itself.
+    __m256i adj_neg_add = _mm256_set1_epi16(-1);
+    return _mm256_madd_epi16(sum, adj_neg_add);
 }
 static INLINE void variance16_kernel_no_sum_avx2(const uint8_t *const src, const int32_t src_stride,
                                                  const uint8_t *const ref, const int32_t ref_stride,
@@ -89,7 +81,7 @@ static INLINE void variance16_no_sum_avx2(const uint8_t *src, const int32_t src_
         const uint8_t *src, int32_t src_stride, const uint8_t *ref, int32_t ref_stride, uint32_t *sse) { \
         __m256i vsse = _mm256_setzero_si256();                                                           \
         variance##bw##_no_sum_avx2(src, src_stride, ref, ref_stride, bh, &vsse);                         \
-        variance_final_##max_pixel##_no_sum_avx2(vsse, sse);                                             \
+        variance_final_from_32bit_no_sum_avx2(vsse, sse);                                                \
     }
 
 AOM_VAR_NO_LOOP_NO_SUM_AVX2(16, 16, 8, 512);
@@ -100,43 +92,47 @@ uint32_t svt_aom_mse16x16_avx2(const uint8_t *src, int32_t src_stride, const uin
     return *sse;
 }
 
-static INLINE int variance_final_from_32bit_sum_avx2(__m256i vsse, __m128i vsum, unsigned int *const sse) {
-    // extract the low lane and add it to the high lane
-    const __m128i sse_reg_128 = mm256_add_hi_lo_epi32(vsse);
-
+static INLINE int variance_final_from_32bit_sum_avx2(__m256i vsse, __m256i vsum, unsigned int *const sse) {
     // unpack sse and sum registers and add
-    const __m128i sse_sum_lo = _mm_unpacklo_epi32(sse_reg_128, vsum);
-    const __m128i sse_sum_hi = _mm_unpackhi_epi32(sse_reg_128, vsum);
-    const __m128i sse_sum    = _mm_add_epi32(sse_sum_lo, sse_sum_hi);
+    const __m256i sse_sum_lo = _mm256_unpacklo_epi32(vsse, vsum);
+    const __m256i sse_sum_hi = _mm256_unpackhi_epi32(vsse, vsum);
+    const __m256i sse_sum    = _mm256_add_epi32(sse_sum_lo, sse_sum_hi);
+
+    // extract the low lane and add it to the high lane
+    const __m128i sse_sum_128 = mm256_add_hi_lo_epi32(sse_sum);
 
     // perform the final summation and extract the results
-    const __m128i res = _mm_add_epi32(sse_sum, _mm_srli_si128(sse_sum, 8));
+    const __m128i res = _mm_add_epi32(sse_sum_128, _mm_srli_si128(sse_sum_128, 8));
     *((int *)sse)     = _mm_cvtsi128_si32(res);
     return _mm_extract_epi32(res, 1);
 }
 
-// handle pixels (<= 512)
-static INLINE int variance_final_512_avx2(__m256i vsse, __m256i vsum, unsigned int *const sse) {
-    // extract the low lane and add it to the high lane
-    const __m128i vsum_128  = mm256_add_hi_lo_epi16(vsum);
-    const __m128i vsum_64   = _mm_add_epi16(vsum_128, _mm_srli_si128(vsum_128, 8));
-    const __m128i sum_int32 = _mm_cvtepi16_epi32(vsum_64);
-    return variance_final_from_32bit_sum_avx2(vsse, sum_int32, sse);
+static INLINE int variance_final_avx2(__m256i vsse, __m256i vsum, unsigned int *const sse) {
+    vsum = neg_sum_to_32bit_avx2(vsum);
+    return variance_final_from_32bit_sum_avx2(vsse, vsum, sse);
 }
 
-// handle 1024 pixels (32x32, 16x64, 64x16)
-static INLINE int variance_final_1024_avx2(__m256i vsse, __m256i vsum, unsigned int *const sse) {
-    // extract the low lane and add it to the high lane
-    const __m128i vsum_128 = mm256_add_hi_lo_epi16(vsum);
-    const __m128i vsum_64  = _mm_add_epi32(_mm_cvtepi16_epi32(vsum_128),
-                                          _mm_cvtepi16_epi32(_mm_srli_si128(vsum_128, 8)));
-    return variance_final_from_32bit_sum_avx2(vsse, vsum_64, sse);
-}
+static INLINE void variance8_kernel_avx2(const uint8_t *const src, const int src_stride, const uint8_t *const ref,
+                                         const int ref_stride, __m256i *const sse, __m256i *const sum) {
+    const __m256i adj_sub = _mm256_set1_epi16(0xff01); // (1,-1)
+    // Load operations. Note that the broadcasts are performed on the load port for no extra cost.
+    const __m128i s0 = _mm_loadl_epi64((__m128i const *)(src + 0 * src_stride));
+    const __m256i s1 = _mm256_broadcastq_epi64(_mm_loadl_epi64((__m128i const *)(src + 1 * src_stride)));
+    const __m128i r0 = _mm_loadl_epi64((__m128i const *)(ref + 0 * ref_stride));
+    const __m256i r1 = _mm256_broadcastq_epi64(_mm_loadl_epi64((__m128i const *)(ref + 1 * ref_stride)));
 
-static INLINE int variance_final_2048_avx2(__m256i vsse, __m256i vsum, unsigned int *const sse) {
-    vsum                   = sum_to_32bit_avx2(vsum);
-    const __m128i vsum_128 = mm256_add_hi_lo_epi32(vsum);
-    return variance_final_from_32bit_sum_avx2(vsse, vsum_128, sse);
+    const __m256i s = _mm256_blend_epi32(_mm256_castsi128_si256(s0), s1, 0xf0);
+    const __m256i r = _mm256_blend_epi32(_mm256_castsi128_si256(r0), r1, 0xf0);
+
+    // unpack into pairs of source and reference values
+    const __m256i src_ref = _mm256_unpacklo_epi8(s, r);
+    // subtract adjacent elements using src*1 + ref*-1
+    const __m256i diff0 = _mm256_maddubs_epi16(src_ref, adj_sub);
+    const __m256i madd0 = _mm256_madd_epi16(diff0, diff0);
+
+    // add to the running totals
+    *sum = _mm256_add_epi16(*sum, diff0);
+    *sse = _mm256_add_epi32(*sse, madd0);
 }
 
 static INLINE void variance_kernel_avx2(const __m256i src, const __m256i ref, __m256i *const sse, __m256i *const sum) {
@@ -175,6 +171,17 @@ static INLINE void variance32_kernel_avx2(const uint8_t *const src, const uint8_
     variance_kernel_avx2(s, r, sse, sum);
 }
 
+static INLINE void variance8_avx2(const uint8_t *src, const int src_stride, const uint8_t *ref, const int ref_stride,
+                                  const int h, __m256i *const vsse, __m256i *const vsum) {
+    *vsum = _mm256_setzero_si256();
+
+    for (int i = 0; i < h; i += 2) {
+        variance8_kernel_avx2(src, src_stride, ref, ref_stride, vsse, vsum);
+        src += 2 * src_stride;
+        ref += 2 * ref_stride;
+    }
+}
+
 static INLINE void variance16_avx2(const uint8_t *src, const int src_stride, const uint8_t *ref, const int ref_stride,
                                    const int h, __m256i *const vsse, __m256i *const vsum) {
     *vsum = _mm256_setzero_si256();
@@ -229,10 +236,15 @@ static INLINE void variance128_avx2(const uint8_t *src, const int src_stride, co
         __m256i vsse = _mm256_setzero_si256();                                                       \
         __m256i vsum;                                                                                \
         variance##bw##_avx2(src, src_stride, ref, ref_stride, bh, &vsse, &vsum);                     \
-        const int sum = variance_final_##max_pixel##_avx2(vsse, vsum, sse);                          \
+        const int sum = variance_final_avx2(vsse, vsum, sse);                                        \
         return *sse - (uint32_t)(((int64_t)sum * sum) >> bits);                                      \
     }
 
+AOM_VAR_NO_LOOP_AVX2(8, 4, 5, 512);
+AOM_VAR_NO_LOOP_AVX2(8, 8, 6, 512);
+AOM_VAR_NO_LOOP_AVX2(8, 16, 7, 512);
+AOM_VAR_NO_LOOP_AVX2(8, 32, 8, 512);
+
 AOM_VAR_NO_LOOP_AVX2(16, 4, 6, 512);
 AOM_VAR_NO_LOOP_AVX2(16, 8, 7, 512);
 AOM_VAR_NO_LOOP_AVX2(16, 16, 8, 512);
@@ -255,12 +267,11 @@ AOM_VAR_NO_LOOP_AVX2(64, 32, 11, 2048);
         for (int i = 0; i < (bh / uh); i++) {                                                        \
             __m256i vsum16;                                                                          \
             variance##bw##_avx2(src, src_stride, ref, ref_stride, uh, &vsse, &vsum16);               \
-            vsum = _mm256_add_epi32(vsum, sum_to_32bit_avx2(vsum16));                                \
+            vsum = _mm256_add_epi32(vsum, neg_sum_to_32bit_avx2(vsum16));                            \
             src += uh * src_stride;                                                                  \
             ref += uh * ref_stride;                                                                  \
         }                                                                                            \
-        const __m128i vsum_128 = mm256_add_hi_lo_epi32(vsum);                                        \
-        const int     sum      = variance_final_from_32bit_sum_avx2(vsse, vsum_128, sse);            \
+        const int sum = variance_final_from_32bit_sum_avx2(vsse, vsum, sse);                         \
         return *sse - (unsigned int)(((int64_t)sum * sum) >> bits);                                  \
     }
 
