@@ -22,7 +22,7 @@
 #define NB_EVEN 5
 #define NB_ODD 4
 
-static INLINE void calc_ab_fast_internal_common(uint32x4_t s0, uint32x4_t s1, uint32x4_t s2, uint32x4_t s3,
+static inline void calc_ab_fast_internal_common(uint32x4_t s0, uint32x4_t s1, uint32x4_t s2, uint32x4_t s3,
                                                 uint32x4_t s4, uint32x4_t s5, uint32x4_t s6, uint32x4_t s7,
                                                 int32x4_t sr4, int32x4_t sr5, int32x4_t sr6, int32x4_t sr7,
                                                 uint32x4_t const_n_val, uint32x4_t s_vec, uint32x4_t const_val,
@@ -109,7 +109,7 @@ static INLINE void calc_ab_fast_internal_common(uint32x4_t s0, uint32x4_t s1, ui
                   vreinterpretq_s32_u32(p3));
 }
 
-static INLINE void calc_ab_internal_common(uint32x4_t s0, uint32x4_t s1, uint32x4_t s2, uint32x4_t s3, uint32x4_t s4,
+static inline void calc_ab_internal_common(uint32x4_t s0, uint32x4_t s1, uint32x4_t s2, uint32x4_t s3, uint32x4_t s4,
                                            uint32x4_t s5, uint32x4_t s6, uint32x4_t s7, uint16x8_t s16_0,
                                            uint16x8_t s16_1, uint16x8_t s16_2, uint16x8_t s16_3, uint16x8_t s16_4,
                                            uint16x8_t s16_5, uint16x8_t s16_6, uint16x8_t s16_7, uint32x4_t const_n_val,
@@ -258,7 +258,7 @@ static INLINE void calc_ab_internal_common(uint32x4_t s0, uint32x4_t s1, uint32x
                   vreinterpretq_s32_u32(p7));
 }
 
-static INLINE void boxsum2_square_sum_calc(int16x4_t t1, int16x4_t t2, int16x4_t t3, int16x4_t t4, int16x4_t t5,
+static inline void boxsum2_square_sum_calc(int16x4_t t1, int16x4_t t2, int16x4_t t3, int16x4_t t4, int16x4_t t5,
                                            int16x4_t t6, int16x4_t t7, int16x4_t t8, int16x4_t t9, int16x4_t t10,
                                            int16x4_t t11, int32x4_t *r0, int32x4_t *r1, int32x4_t *r2, int32x4_t *r3) {
     int32x4_t d1, d2, d3, d4, d5, d6, d7, d8, d9, d10, d11;
@@ -291,7 +291,7 @@ static INLINE void boxsum2_square_sum_calc(int16x4_t t1, int16x4_t t2, int16x4_t
     *r3   = vaddq_s32(r789, r1011);
 }
 
-static INLINE void boxsum2(int16_t *src, const int src_stride, int16_t *dst16, int32_t *dst32, int32_t *dst2,
+static inline void boxsum2(int16_t *src, const int src_stride, int16_t *dst16, int32_t *dst32, int32_t *dst2,
                            const int dst_stride, const int width, const int height) {
     assert(width > 2 * SGRPROJ_BORDER_HORZ);
     assert(height > 2 * SGRPROJ_BORDER_VERT);
@@ -484,7 +484,7 @@ static INLINE void boxsum2(int16_t *src, const int src_stride, int16_t *dst16, i
     }
 }
 
-static INLINE void calc_ab_internal_lbd(int32_t *A, uint16_t *A16, uint16_t *B16, int32_t *B, const int buf_stride,
+static inline void calc_ab_internal_lbd(int32_t *A, uint16_t *A16, uint16_t *B16, int32_t *B, const int buf_stride,
                                         const int width, const int height, const int r, const int s, const int ht_inc) {
     int32_t         *src1, *dst2, count = 0;
     uint16_t        *dst_A16, *src2;
@@ -554,7 +554,7 @@ static INLINE void calc_ab_internal_lbd(int32_t *A, uint16_t *A16, uint16_t *B16
     } while (h > 0);
 }
 
-static INLINE void calc_ab_internal_hbd(int32_t *A, uint16_t *A16, uint16_t *B16, int32_t *B, const int buf_stride,
+static inline void calc_ab_internal_hbd(int32_t *A, uint16_t *A16, uint16_t *B16, int32_t *B, const int buf_stride,
                                         const int width, const int height, const int bit_depth, const int r,
                                         const int s, const int ht_inc) {
     int32_t         *src1, *dst2, count = 0;
@@ -637,7 +637,7 @@ static INLINE void calc_ab_internal_hbd(int32_t *A, uint16_t *A16, uint16_t *B16
     } while (h > 0);
 }
 
-static INLINE void calc_ab_fast_internal_lbd(int32_t *A, uint16_t *A16, int32_t *B, const int buf_stride,
+static inline void calc_ab_fast_internal_lbd(int32_t *A, uint16_t *A16, int32_t *B, const int buf_stride,
                                              const int width, const int height, const int r, const int s,
                                              const int ht_inc) {
     int32_t         *src1, *src2, count = 0;
@@ -704,7 +704,7 @@ static INLINE void calc_ab_fast_internal_lbd(int32_t *A, uint16_t *A16, int32_t
     } while (h > 0);
 }
 
-static INLINE void calc_ab_fast_internal_hbd(int32_t *A, uint16_t *A16, int32_t *B, const int buf_stride,
+static inline void calc_ab_fast_internal_hbd(int32_t *A, uint16_t *A16, int32_t *B, const int buf_stride,
                                              const int width, const int height, const int bit_depth, const int r,
                                              const int s, const int ht_inc) {
     int32_t         *src1, *src2, count = 0;
@@ -773,7 +773,7 @@ static INLINE void calc_ab_fast_internal_hbd(int32_t *A, uint16_t *A16, int32_t
     } while (h > 0);
 }
 
-static INLINE void boxsum1(int16_t *src, const int src_stride, uint16_t *dst1, int32_t *dst2, const int dst_stride,
+static inline void boxsum1(int16_t *src, const int src_stride, uint16_t *dst1, int32_t *dst2, const int dst_stride,
                            const int width, const int height) {
     assert(width > 2 * SGRPROJ_BORDER_HORZ);
     assert(height > 2 * SGRPROJ_BORDER_VERT);
@@ -976,7 +976,7 @@ static INLINE void boxsum1(int16_t *src, const int src_stride, uint16_t *dst1, i
     }
 }
 
-static INLINE int32x4_t cross_sum_inp_s32(int32_t *buf, int buf_stride) {
+static inline int32x4_t cross_sum_inp_s32(int32_t *buf, int buf_stride) {
     int32x4_t xtr, xt, xtl, xl, x, xr, xbr, xb, xbl;
     int32x4_t fours, threes, res;
 
@@ -996,7 +996,7 @@ static INLINE int32x4_t cross_sum_inp_s32(int32_t *buf, int buf_stride) {
     return res;
 }
 
-static INLINE void cross_sum_inp_u16(uint16_t *buf, int buf_stride, int32x4_t *a0, int32x4_t *a1) {
+static inline void cross_sum_inp_u16(uint16_t *buf, int buf_stride, int32x4_t *a0, int32x4_t *a1) {
     uint16x8_t xtr, xt, xtl, xl, x, xr, xbr, xb, xbl;
     uint16x8_t r0, r1;
 
@@ -1028,7 +1028,7 @@ static INLINE void cross_sum_inp_u16(uint16_t *buf, int buf_stride, int32x4_t *a
     *a1 = vreinterpretq_s32_u32(vaddq_u32(vmovl_u16(vget_high_u16(r0)), vmovl_u16(vget_high_u16(r1))));
 }
 
-static INLINE int32x4_t cross_sum_fast_even_row(int32_t *buf, int buf_stride) {
+static inline int32x4_t cross_sum_fast_even_row(int32_t *buf, int buf_stride) {
     int32x4_t xtr, xt, xtl, xbr, xb, xbl;
     int32x4_t fives, sixes, fives_plus_sixes;
 
@@ -1046,7 +1046,7 @@ static INLINE int32x4_t cross_sum_fast_even_row(int32_t *buf, int buf_stride) {
     return vaddq_s32(vaddq_s32(vshlq_n_s32(fives_plus_sixes, 2), fives_plus_sixes), sixes);
 }
 
-static INLINE void cross_sum_fast_even_row_inp16(uint16_t *buf, int buf_stride, int32x4_t *a0, int32x4_t *a1) {
+static inline void cross_sum_fast_even_row_inp16(uint16_t *buf, int buf_stride, int32x4_t *a0, int32x4_t *a1) {
     uint16x8_t xtr, xt, xtl, xbr, xb, xbl, xb0;
 
     xtl = vld1q_u16(buf - buf_stride - 1);
@@ -1071,7 +1071,7 @@ static INLINE void cross_sum_fast_even_row_inp16(uint16_t *buf, int buf_stride,
     *a1 = vreinterpretq_s32_u32(vaddq_u32(vmovl_u16(vget_high_u16(xbr)), vmovl_u16(vget_high_u16(xb))));
 }
 
-static INLINE int32x4_t cross_sum_fast_odd_row(int32_t *buf) {
+static inline int32x4_t cross_sum_fast_odd_row(int32_t *buf) {
     int32x4_t xl, x, xr;
     int32x4_t fives, sixes, fives_plus_sixes;
 
@@ -1085,7 +1085,7 @@ static INLINE int32x4_t cross_sum_fast_odd_row(int32_t *buf) {
     return vaddq_s32(vaddq_s32(vshlq_n_s32(fives_plus_sixes, 2), fives_plus_sixes), sixes);
 }
 
-static INLINE void cross_sum_fast_odd_row_inp16(uint16_t *buf, int32x4_t *a0, int32x4_t *a1) {
+static inline void cross_sum_fast_odd_row_inp16(uint16_t *buf, int32x4_t *a0, int32x4_t *a1) {
     uint16x8_t xl, x, xr;
     uint16x8_t x0;
 
@@ -1227,7 +1227,7 @@ static void final_filter_internal(uint16_t *A, int32_t *B, const int buf_stride,
     } while (h > 0);
 }
 
-static INLINE void restoration_fast_internal(uint16_t *dgd16, int width, int height, int dgd_stride, int32_t *dst,
+static inline void restoration_fast_internal(uint16_t *dgd16, int width, int height, int dgd_stride, int32_t *dst,
                                              int dst_stride, int bit_depth, int sgr_params_idx, int radius_idx) {
     const SgrParamsType *const params     = &svt_aom_eb_sgr_params[sgr_params_idx];
     const int                  r          = params->r[radius_idx];
@@ -1294,7 +1294,7 @@ static INLINE void restoration_fast_internal(uint16_t *dgd16, int width, int hei
         tmp16_buf, sum_buf, buf_stride, (int16_t *)dgd16, dgd_stride, dst, dst_stride, width, height);
 }
 
-static INLINE void restoration_internal(uint16_t *dgd16, int width, int height, int dgd_stride, int32_t *dst,
+static inline void restoration_internal(uint16_t *dgd16, int width, int height, int dgd_stride, int32_t *dst,
                                         int dst_stride, int bit_depth, int sgr_params_idx, int radius_idx) {
     const SgrParamsType *const params     = &svt_aom_eb_sgr_params[sgr_params_idx];
     const int                  r          = params->r[radius_idx];
@@ -1363,7 +1363,7 @@ static INLINE void restoration_internal(uint16_t *dgd16, int width, int height,
     final_filter_internal(A16, B, buf_stride, (int16_t *)dgd16, dgd_stride, dst, dst_stride, width, height);
 }
 
-static INLINE void src_convert_u8_to_u16(const uint8_t *src, const int src_stride, uint16_t *dst, const int dst_stride,
+static inline void src_convert_u8_to_u16(const uint8_t *src, const int src_stride, uint16_t *dst, const int dst_stride,
                                          const int width, const int height) {
     const uint8_t *src_ptr;
     uint16_t      *dst_ptr;
@@ -1413,7 +1413,7 @@ static INLINE void src_convert_u8_to_u16(const uint8_t *src, const int src_strid
     for (x = height; x < height + 5; x++) memset(dst + x * dst_stride, 0, (width + 2) * sizeof(*dst));
 }
 
-static INLINE void src_convert_hbd_copy(const uint16_t *src, int src_stride, uint16_t *dst, const int dst_stride,
+static inline void src_convert_hbd_copy(const uint16_t *src, int src_stride, uint16_t *dst, const int dst_stride,
                                         int width, int height) {
     const uint16_t *src_ptr;
     uint16_t       *dst_ptr;
@@ -1518,7 +1518,7 @@ static const sgr_params_type av1_sgr_params[SGRPROJ_PARAMS] = {
     {{2, 0}, {22, -1}},
 };
 
-static INLINE void av1_decode_xq(const int *xqd, int *xq, const sgr_params_type *params) {
+static inline void av1_decode_xq(const int *xqd, int *xq, const sgr_params_type *params) {
     if (params->r[0] == 0) {
         xq[0] = 0;
         xq[1] = (1 << SGRPROJ_PRJ_BITS) - xqd[1];
