@@ -13,18 +13,20 @@
 
 #include "definitions.h"
 #include "cdef.h"
+#include "pcs.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
-typedef void (*CdefFilterBlockFunc)(uint8_t *dst8, uint16_t *dst16, int32_t dstride, const uint16_t *in,
+typedef void (*CdefFilterBlockFunc)(uint8_t* dst8, uint16_t* dst16, int32_t dstride, const uint16_t* in,
                                     int32_t pri_strength, int32_t sec_strength, int32_t dir, int32_t pri_damping,
                                     int32_t sec_damping, int32_t bsize, int32_t coeff_shift,
                                     uint8_t subsampling_factor);
 
-void copy_cdef_16bit_to_16bit(uint16_t *dst, int32_t dstride, uint16_t *src, CdefList *dlist, int32_t cdef_count,
-                              int32_t bsize);
-
+int32_t svt_sb_compute_cdef_list(PictureControlSet* pcs, const Av1Common* const cm, int32_t mi_row, int32_t mi_col,
+                                 CdefList* dlist, BlockSize bs);
+void    finish_cdef_search(PictureControlSet* pcs);
+void    svt_av1_cdef_frame(struct SequenceControlSet* scs, PictureControlSet* pcs);
 #ifdef __cplusplus
 }
 #endif
