@@ -26,7 +26,7 @@ void svt_aom_setup_segmentation(PictureControlSet *pcs, SequenceControlSet *scs)
 
 void find_segment_qps(SegmentationParams *segmentation_params, PictureControlSet *pcs);
 
-void temporally_update_qps(int32_t *segment_qp_ptr, int32_t *prev_segment_qp_ptr, Bool temporal_update);
+void temporally_update_qps(int32_t *segment_qp_ptr, int32_t *prev_segment_qp_ptr, bool temporal_update);
 
 void calculate_segmentation_data(SegmentationParams *segmentation_params);
 
