@@ -349,7 +349,7 @@ static int16_t resolve_divisor_32(uint32_t D, int16_t *shift) {
     return div_lut[f];
 }
 
-static int is_affine_valid(const EbWarpedMotionParams *const wm) {
+static int is_affine_valid(const WarpedMotionParams *const wm) {
     const int32_t *mat = wm->wmmat;
     return (mat[2] > 0);
 }
@@ -362,8 +362,8 @@ static int is_affine_shear_allowed(int16_t alpha, int16_t beta, int16_t gamma, i
         return 1;
 }
 
-static int find_affine_int(int np, const int *pts1, const int *pts2, BlockSize bsize, int mvy, int mvx,
-                           EbWarpedMotionParams *wm, int mi_row, int mi_col) {
+static int find_affine_int(int np, const int *pts1, const int *pts2, BlockSize bsize, Mv mv, WarpedMotionParams *wm,
+                           int mi_row, int mi_col) {
     int32_t A[2][2] = {{0, 0}, {0, 0}};
     int32_t bx[2]   = {0, 0};
     int32_t by[2]   = {0, 0};
@@ -375,8 +375,8 @@ static int find_affine_int(int np, const int *pts1, const int *pts2, BlockSize b
     const int rsux = (AOMMAX(bw, MI_SIZE) / 2 - 1);
     const int suy  = rsuy * 8;
     const int sux  = rsux * 8;
-    const int duy  = suy + mvy;
-    const int dux  = sux + mvx;
+    const int duy  = suy + mv.y;
+    const int dux  = sux + mv.x;
     const int isuy = (mi_row * MI_SIZE + rsuy);
     const int isux = (mi_col * MI_SIZE + rsux);
 
@@ -459,20 +459,19 @@ static int find_affine_int(int np, const int *pts1, const int *pts2, BlockSize b
     // 2nd and 3rd terms are (2^16 - 1) * (2^13 - 1). That leaves enough room
     // for the first term so that the overall sum in the worst case fits
     // within 32 bits overall.
-    int32_t vx = mvx * (1 << (WARPEDMODEL_PREC_BITS - 3)) -
+    int32_t vx = mv.x * (1 << (WARPEDMODEL_PREC_BITS - 3)) -
         (isux * (wm->wmmat[2] - (1 << WARPEDMODEL_PREC_BITS)) + isuy * wm->wmmat[3]);
-    int32_t vy = mvy * (1 << (WARPEDMODEL_PREC_BITS - 3)) -
+    int32_t vy = mv.y * (1 << (WARPEDMODEL_PREC_BITS - 3)) -
         (isux * wm->wmmat[4] + isuy * (wm->wmmat[5] - (1 << WARPEDMODEL_PREC_BITS)));
     wm->wmmat[0] = clamp(vx, -WARPEDMODEL_TRANS_CLAMP, WARPEDMODEL_TRANS_CLAMP - 1);
     wm->wmmat[1] = clamp(vy, -WARPEDMODEL_TRANS_CLAMP, WARPEDMODEL_TRANS_CLAMP - 1);
 
-    wm->wmmat[6] = wm->wmmat[7] = 0;
     return 0;
 }
 
-Bool svt_find_projection(int np, int *pts1, int *pts2, BlockSize bsize, int mvy, int mvx,
-                         EbWarpedMotionParams *wm_params, int mi_row, int mi_col) {
-    if (find_affine_int(np, pts1, pts2, bsize, mvy, mvx, wm_params, mi_row, mi_col)) {
+bool svt_find_projection(int np, int *pts1, int *pts2, BlockSize bsize, Mv mv, WarpedMotionParams *wm_params,
+                         int mi_row, int mi_col) {
+    if (find_affine_int(np, pts1, pts2, bsize, mv, wm_params, mi_row, mi_col)) {
         return 1;
     }
 
@@ -679,9 +678,9 @@ void svt_av1_warp_affine_c(const int32_t *mat, const uint8_t *ref, int width, in
     }
 }
 
-void svt_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref, int width, int height, int stride,
-                    uint8_t *pred, int p_col, int p_row, int p_width, int p_height, int p_stride, int subsampling_x,
-                    int subsampling_y, ConvolveParams *conv_params) {
+void svt_warp_plane(WarpedMotionParams *wm, const uint8_t *const ref, int width, int height, int stride, uint8_t *pred,
+                    int p_col, int p_row, int p_width, int p_height, int p_stride, int subsampling_x, int subsampling_y,
+                    ConvolveParams *conv_params) {
     assert(wm->wmtype <= AFFINE);
     if (wm->wmtype == ROTZOOM) {
         wm->wmmat[5] = wm->wmmat[2];
@@ -712,113 +711,6 @@ void svt_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref, int widt
                         delta);
 }
 
-/* Note: For an explanation of the warp algorithm, and some notes on bit widths
-    for hardware implementations, see the comments above svt_av1_warp_affine_c
-*/
-void svt_aom_dec_svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint16_t *ref, int width, int height,
-                                              int stride, uint16_t *pred, int p_col, int p_row, int p_width,
-                                              int p_height, int p_stride, int subsampling_x, int subsampling_y, int bd,
-                                              ConvolveParams *conv_params, int16_t alpha, int16_t beta, int16_t gamma,
-                                              int16_t delta) {
-    int32_t   tmp[15 * 8];
-    const int reduce_bits_horiz = conv_params->round_0 + AOMMAX(bd + FILTER_BITS - conv_params->round_0 - 14, 0);
-    const int reduce_bits_vert  = conv_params->is_compound ? conv_params->round_1 : 2 * FILTER_BITS - reduce_bits_horiz;
-    const int max_bits_horiz    = bd + FILTER_BITS + 1 - reduce_bits_horiz;
-    const int offset_bits_horiz = bd + FILTER_BITS - 1;
-    const int offset_bits_vert  = bd + 2 * FILTER_BITS - reduce_bits_horiz;
-    const int round_bits        = 2 * FILTER_BITS - conv_params->round_0 - conv_params->round_1;
-    const int offset_bits       = bd + 2 * FILTER_BITS - conv_params->round_0;
-    (void)max_bits_horiz;
-    assert(IMPLIES(conv_params->is_compound, conv_params->dst != NULL));
-
-    for (int i = p_row; i < p_row + p_height; i += 8) {
-        for (int j = p_col; j < p_col + p_width; j += 8) {
-            // Calculate the center of this 8x8 block,
-            // project to luma coordinates (if in a subsampled chroma plane),
-            // apply the affine transformation,
-            // then convert back to the original coordinates (if necessary)
-            const int32_t src_x = (j + 4) << subsampling_x;
-            const int32_t src_y = (i + 4) << subsampling_y;
-            const int32_t dst_x = mat[2] * src_x + mat[3] * src_y + mat[0];
-            const int32_t dst_y = mat[4] * src_x + mat[5] * src_y + mat[1];
-            const int32_t x4    = dst_x >> subsampling_x;
-            const int32_t y4    = dst_y >> subsampling_y;
-
-            const int32_t ix4 = x4 >> WARPEDMODEL_PREC_BITS;
-            int32_t       sx4 = x4 & ((1 << WARPEDMODEL_PREC_BITS) - 1);
-            const int32_t iy4 = y4 >> WARPEDMODEL_PREC_BITS;
-            int32_t       sy4 = y4 & ((1 << WARPEDMODEL_PREC_BITS) - 1);
-
-            sx4 += alpha * (-4) + beta * (-4);
-            sy4 += gamma * (-4) + delta * (-4);
-
-            sx4 &= ~((1 << WARP_PARAM_REDUCE_BITS) - 1);
-            sy4 &= ~((1 << WARP_PARAM_REDUCE_BITS) - 1);
-
-            // Horizontal filter
-            for (int k = -7; k < 8; ++k) {
-                const int iy = clamp(iy4 + k, 0, height - 1);
-
-                int sx = sx4 + beta * (k + 4);
-                for (int l = -4; l < 4; ++l) {
-                    int       ix   = ix4 + l - 3;
-                    const int offs = ROUND_POWER_OF_TWO(sx, WARPEDDIFF_PREC_BITS) + WARPEDPIXEL_PREC_SHIFTS;
-                    assert(offs >= 0 && offs <= WARPEDPIXEL_PREC_SHIFTS * 3);
-                    const int16_t *coeffs = svt_aom_warped_filter[offs];
-
-                    int32_t sum = 1 << offset_bits_horiz;
-                    for (int m = 0; m < 8; ++m) {
-                        const int sample_x = clamp(ix + m, 0, width - 1);
-                        sum += ref[iy * stride + sample_x] * coeffs[m];
-                    }
-                    sum = ROUND_POWER_OF_TWO(sum, reduce_bits_horiz);
-                    assert(0 <= sum && sum < (1 << max_bits_horiz));
-                    tmp[(k + 7) * 8 + (l + 4)] = sum;
-                    sx += alpha;
-                }
-            }
-
-            // Vertical filter
-            for (int k = -4; k < AOMMIN(4, p_row + p_height - i - 4); ++k) {
-                int sy = sy4 + delta * (k + 4);
-                for (int l = -4; l < AOMMIN(4, p_col + p_width - j - 4); ++l) {
-                    const int offs = ROUND_POWER_OF_TWO(sy, WARPEDDIFF_PREC_BITS) + WARPEDPIXEL_PREC_SHIFTS;
-                    assert(offs >= 0 && offs <= WARPEDPIXEL_PREC_SHIFTS * 3);
-                    const int16_t *coeffs = svt_aom_warped_filter[offs];
-
-                    int32_t sum = 1 << offset_bits_vert;
-                    for (int m = 0; m < 8; ++m) sum += tmp[(k + m + 4) * 8 + (l + 4)] * coeffs[m];
-                    if (conv_params->is_compound) {
-                        ConvBufType *p =
-                            &conv_params->dst[(i - p_row + k + 4) * conv_params->dst_stride + (j - p_col + l + 4)];
-                        sum = ROUND_POWER_OF_TWO(sum, reduce_bits_vert);
-                        if (conv_params->do_average) {
-                            uint16_t *dst16 = &pred[(i - p_row + k + 4) * p_stride + (j - p_col + l + 4)];
-                            int32_t   tmp32 = *p;
-                            if (conv_params->use_jnt_comp_avg) {
-                                tmp32 = tmp32 * conv_params->fwd_offset + sum * conv_params->bck_offset;
-                                tmp32 = tmp32 >> DIST_PRECISION_BITS;
-                            } else {
-                                tmp32 += sum;
-                                tmp32 = tmp32 >> 1;
-                            }
-                            tmp32 = tmp32 - (1 << (offset_bits - conv_params->round_1)) -
-                                (1 << (offset_bits - conv_params->round_1 - 1));
-                            *dst16 = clip_pixel_highbd(ROUND_POWER_OF_TWO(tmp32, round_bits), bd);
-                        } else
-                            *p = sum;
-                    } else {
-                        uint16_t *p = &pred[(i - p_row + k + 4) * p_stride + (j - p_col + l + 4)];
-                        sum         = ROUND_POWER_OF_TWO(sum, reduce_bits_vert);
-                        assert(0 <= sum && sum < (1 << (bd + 2)));
-                        *p = clip_pixel_highbd(sum - (1 << (bd - 1)) - (1 << bd), bd);
-                    }
-                    sy += gamma;
-                }
-            }
-        }
-    }
-}
 void svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint8_t *ref8b, const uint8_t *ref2b, int width, int height,
                                   int stride8b, int stride2b, uint16_t *pred, int p_col, int p_row, int p_width,
                                   int p_height, int p_stride, int subsampling_x, int subsampling_y, int bd,
@@ -926,46 +818,7 @@ void svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint8_t *ref8b, cons
     }
 }
 
-void dec_svt_highbd_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref8, int width, int height, int stride,
-                               const uint8_t *const pred8, int p_col, int p_row, int p_width, int p_height,
-                               int p_stride, int subsampling_x, int subsampling_y, int bd,
-                               ConvolveParams *conv_params) {
-    assert(wm->wmtype <= AFFINE);
-    if (wm->wmtype == ROTZOOM) {
-        wm->wmmat[5] = wm->wmmat[2];
-        wm->wmmat[4] = -wm->wmmat[3];
-    }
-    const int32_t *const mat   = wm->wmmat;
-    const int16_t        alpha = wm->alpha;
-    const int16_t        beta  = wm->beta;
-    const int16_t        gamma = wm->gamma;
-    const int16_t        delta = wm->delta;
-
-    const uint16_t *const ref = (uint16_t *)ref8;
-
-    uint16_t *pred = (uint16_t *)pred8;
-
-    dec_svt_av1_highbd_warp_affine(mat,
-                                   ref,
-                                   width,
-                                   height,
-                                   stride,
-                                   pred,
-                                   p_col,
-                                   p_row,
-                                   p_width,
-                                   p_height,
-                                   p_stride,
-                                   subsampling_x,
-                                   subsampling_y,
-                                   bd,
-                                   conv_params,
-                                   alpha,
-                                   beta,
-                                   gamma,
-                                   delta);
-}
-void svt_highbd_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref8, const uint8_t *const ref_2b, int width,
+void svt_highbd_warp_plane(WarpedMotionParams *wm, const uint8_t *const ref8, const uint8_t *const ref_2b, int width,
                            int height, int stride, const uint8_t *const pred8, int p_col, int p_row, int p_width,
                            int p_height, int p_stride, int subsampling_x, int subsampling_y, int bd,
                            ConvolveParams *conv_params) {
@@ -1004,7 +857,7 @@ void svt_highbd_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref8,
                                delta);
 }
 
-void svt_av1_warp_plane(EbWarpedMotionParams *wm, int use_hbd, int bd, const uint8_t *ref, const uint8_t *ref_2b,
+void svt_av1_warp_plane(WarpedMotionParams *wm, int use_hbd, int bd, const uint8_t *ref, const uint8_t *ref_2b,
                         int width, int height, int stride, uint8_t *pred, int p_col, int p_row, int p_width,
                         int p_height, int p_stride, int subsampling_x, int subsampling_y, ConvolveParams *conv_params) {
     if (use_hbd)
@@ -1042,7 +895,7 @@ void svt_av1_warp_plane(EbWarpedMotionParams *wm, int use_hbd, int bd, const uin
 }
 
 // Returns 1 on success or 0 on an invalid affine set
-int svt_get_shear_params(EbWarpedMotionParams *wm) {
+int svt_get_shear_params(WarpedMotionParams *wm) {
     const int32_t *mat = wm->wmmat;
     if (!is_affine_valid(wm))
         return 0;
@@ -1068,52 +921,23 @@ int svt_get_shear_params(EbWarpedMotionParams *wm) {
 }
 
 // Select samples according to the motion vector difference.
-int svt_aom_select_samples(MV *mv, int *pts, int *pts_inref, int len, BlockSize bsize) {
-    const uint8_t bw                          = block_size_wide[bsize];
-    const uint8_t bh                          = block_size_high[bsize];
-    const int     thresh                      = clamp(AOMMAX(bw, bh), 16, 112);
-    int           pts_mvd[SAMPLES_ARRAY_SIZE] = {0};
-    int           i, j, k, l = len;
-    int           ret = 0;
+uint8_t svt_aom_select_samples(Mv mv, int *pts, int *pts_inref, int len, BlockSize bsize) {
+    const int bw     = block_size_wide[bsize];
+    const int bh     = block_size_high[bsize];
+    const int thresh = clamp(AOMMAX(bw, bh), 16, 112);
+    uint8_t   ret    = 0;
 
-    // Obtain the motion vector difference.
-    for (i = 0; i < len; ++i) {
-        pts_mvd[i] = abs(pts_inref[2 * i] - pts[2 * i] - mv->col) +
-            abs(pts_inref[2 * i + 1] - pts[2 * i + 1] - mv->row);
-
-        if (pts_mvd[i] > thresh)
-            pts_mvd[i] = -1;
-        else
-            ret++;
-    }
-
-    // Keep at least 1 sample.
-    if (!ret)
-        return 1;
-
-    i = 0;
-    j = l - 1;
-    for (k = 0; k < l - ret; k++) {
-        while (pts_mvd[i] != -1) i++;
-        if (j < 0)
-            break;
-        while (pts_mvd[j] == -1) {
-            j--;
-            if (j < 0)
-                break;
+    // Only keep the samples with MV differences within threshold.
+    for (int i = 0; i < len; ++i) {
+        const int diff = abs(pts_inref[2 * i] - pts[2 * i] - mv.x) + abs(pts_inref[2 * i + 1] - pts[2 * i + 1] - mv.y);
+        if (diff > thresh)
+            continue;
+        if (ret != i) {
+            memcpy(pts + 2 * ret, pts + 2 * i, 2 * sizeof(pts[0]));
+            memcpy(pts_inref + 2 * ret, pts_inref + 2 * i, 2 * sizeof(pts_inref[0]));
         }
-        if (i > j)
-            break;
-
-        // Replace the discarded samples;
-        pts_mvd[i]           = pts_mvd[j];
-        pts[2 * i]           = pts[2 * j];
-        pts[2 * i + 1]       = pts[2 * j + 1];
-        pts_inref[2 * i]     = pts_inref[2 * j];
-        pts_inref[2 * i + 1] = pts_inref[2 * j + 1];
-        i++;
-        j--;
+        ++ret;
     }
-
-    return ret;
+    // Keep at least 1 sample.
+    return AOMMAX(ret, 1);
 }
