@@ -76,7 +76,12 @@ class CompBlendTest : public ::testing::TestWithParam<BlendTestParam> {
 
     void run_test() {
         const int iterations = 1000;
-        int max = is_d16_ ? 16 : bd_;
+        /*
+          // max number of bits used by the source for d16 blends is as follows
+          (from libaom): static const int kSrcMaxBitsMask = (1 << 14) - 1;
+          static const int kSrcMaxBitsMaskHBD = (1 << 16) - 1;
+        */
+        int max = is_d16_ ? (bd_ == 8 ? 14 : 16) : bd_;
         SVTRandom rnd(0, (1 << max) - 1);
         SVTRandom mask_rnd(0, 64);
 
@@ -226,7 +231,7 @@ class LbdCompBlendD16Test
                            MAKE_PARAM(LbdBlendA64D16MaskFunc)> {
   public:
     LbdCompBlendD16Test() {
-        bd_ = 10;
+        bd_ = 8;
         func_ref_ = TEST_GET_PARAM(0);
         func_tst_ = TEST_GET_PARAM(1);
         is_d16_ = true;
@@ -270,17 +275,16 @@ TEST_P(LbdCompBlendD16Test, BlendA64MaskD16) {
     run_test();
 }
 
-// TODO: Re-enable when the overflow is fixed.
-// #ifdef ARCH_X86_64
-// INSTANTIATE_TEST_SUITE_P(
-//    SSE4_1, LbdCompBlendD16Test,
-//    ::testing::ValuesIn({make_tuple(svt_aom_lowbd_blend_a64_d16_mask_c,
-//                                    svt_aom_lowbd_blend_a64_d16_mask_sse4_1)}));
-// INSTANTIATE_TEST_SUITE_P(
-//    AVX2, LbdCompBlendD16Test,
-//    ::testing::ValuesIn({make_tuple(svt_aom_lowbd_blend_a64_d16_mask_c,
-//                                    svt_aom_lowbd_blend_a64_d16_mask_avx2)}));
-// #endif  // ARCH_X86_64
+#ifdef ARCH_X86_64
+INSTANTIATE_TEST_SUITE_P(
+    SSE4_1, LbdCompBlendD16Test,
+    ::testing::ValuesIn({make_tuple(svt_aom_lowbd_blend_a64_d16_mask_c,
+                                    svt_aom_lowbd_blend_a64_d16_mask_sse4_1)}));
+INSTANTIATE_TEST_SUITE_P(
+    AVX2, LbdCompBlendD16Test,
+    ::testing::ValuesIn({make_tuple(svt_aom_lowbd_blend_a64_d16_mask_c,
+                                    svt_aom_lowbd_blend_a64_d16_mask_avx2)}));
+#endif  // ARCH_X86_64
 
 #ifdef ARCH_AARCH64
 INSTANTIATE_TEST_SUITE_P(
@@ -1298,7 +1302,6 @@ class AomHighbdSubtractBlockTest
   private:
     SVTRandom rnd_;
 };
-GTEST_ALLOW_UNINSTANTIATED_PARAMETERIZED_TEST(AomHighbdSubtractBlockTest);
 
 TEST_P(AomHighbdSubtractBlockTest, MatchTest) {
     run_test();
@@ -1311,4 +1314,11 @@ INSTANTIATE_TEST_SUITE_P(
                        ::testing::Values(svt_aom_highbd_subtract_block_sse2)));
 #endif  // ARCH_X86_64
 
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    NEON, AomHighbdSubtractBlockTest,
+    ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
+                       ::testing::Values(svt_aom_highbd_subtract_block_neon)));
+#endif  // ARCH_AARCH64
+
 }  // namespace
