@@ -25,19 +25,11 @@
 #include <stdint.h>
 #include <stdlib.h>
 #include <sstream>
-#include "gtest/gtest.h"
-// workaround to eliminate the compiling warning on linux
-// The macro will conflict with definition in gtest.h
-#ifdef __USE_GNU
-#undef __USE_GNU  // defined in EbThreads.h
-#endif
-#ifdef _GNU_SOURCE
-#undef _GNU_SOURCE  // defined in EbThreads.h
-#endif
 
+#include "gtest/gtest.h"
 #include "random.h"
 #include "util.h"
-#include "EbUtility.h"
+#include "utility.h"
 #include "aom_dsp_rtcd.h"
 
 using svt_av1_test_tool::SVTRandom;
@@ -116,7 +108,6 @@ class FFT2DTest : public ::testing::TestWithParam<FFT2DTestParam> {
         svt_aom_free(temp_ref_);
         svt_aom_free(output_tst_);
         svt_aom_free(output_ref_);
-        aom_clear_system_state();
     }
 
     void run_fft_accuracy_check() {
@@ -188,7 +179,7 @@ TEST_P(FFT2DTest, run_fft_ifft_check) {
     run_fft_ifft_check();
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     FFT, FFT2DTest,
     ::testing::Values(
         FFT2DTestParam(svt_aom_fft2x2_float_c, svt_aom_fft2x2_float_c,
@@ -244,7 +235,6 @@ class IFFT2DTest : public ::testing::TestWithParam<IFFT2DTestParam> {
         svt_aom_free(temp_ref_);
         svt_aom_free(output_tst_);
         svt_aom_free(output_ref_);
-        aom_clear_system_state();
     }
 
     void run_ifft_accuracy_check() {
@@ -286,7 +276,7 @@ TEST_P(IFFT2DTest, run_ifft_accuracy_check) {
     run_ifft_accuracy_check();
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     IFFT, IFFT2DTest,
     ::testing::Values(
         IFFT2DTestParam(svt_aom_ifft2x2_float_c, svt_aom_ifft2x2_float_c, 2),
