@@ -25,17 +25,10 @@
  *
  ******************************************************************************/
 #include <vector>
+
 #include "gtest/gtest.h"
-// workaround to eliminate the compiling warning on linux
-// The macro will conflict with definition in gtest.h
-#ifdef __USE_GNU
-#undef __USE_GNU  // defined in EbThreads.h
-#endif
-#ifdef _GNU_SOURCE
-#undef _GNU_SOURCE  // defined in EbThreads.h
-#endif
-#include "EbDefinitions.h"
-#include "EbUtility.h"
+#include "definitions.h"
+#include "utility.h"
 extern "C" {
 #include "ransac.h"
 }
@@ -90,7 +83,7 @@ static const int PointCountMin = 15; /**< 3*MINPTS_MULTIPLIER */
  * should be less than threshold
  *
  */
-template <typename Sample, typename FuncType>
+template <typename Sample>
 class RansacTest : public ::testing::TestWithParam<TransformationType> {
   protected:
     RansacTest() : rnd_(0, CoordinateMax) {
@@ -140,8 +133,6 @@ class RansacTest : public ::testing::TestWithParam<TransformationType> {
 
     virtual void prepare_input(Sample *input, int npoints) = 0;
 
-    virtual FuncType get_ransac_func(TransformationType type) = 0;
-
     void do_ransac_check() {
         const int npoints = (int)data_.size();
         Sample *points = new Sample[npoints * 4];
@@ -162,14 +153,17 @@ class RansacTest : public ::testing::TestWithParam<TransformationType> {
             memset(motions[i].inliers, 0, sizeof(int) * 2 * npoints);
         }
 
-        FuncType ransac_func = (FuncType)get_ransac_func(GetParam());
-        ASSERT_NE(ransac_func, nullptr);
-        int ret = ransac_func(
-            points, npoints, num_inliers_by_motion, motions, num_motions);
-        ASSERT_EQ(ret, 0);
+        bool mem_alloc_failed = false;
+        bool ret = svt_aom_ransac((Correspondence *)points,
+                                  npoints,
+                                  GetParam(),
+                                  motions,
+                                  num_motions,
+                                  &mem_alloc_failed);
+        ASSERT_EQ(ret, true);
 
         /** check for the number of inlier */
-        ASSERT_NE(num_inliers_by_motion[0], 0);
+        ASSERT_NE(motions[0].num_inliers, 0);
 
         /** check for the transform matrix of motion */
         check_transform_matrix(mat_, motions[0].params);
@@ -333,7 +327,7 @@ class RansacTest : public ::testing::TestWithParam<TransformationType> {
     AffineMat mat_;
 };
 
-class RansacIntTest : public RansacTest<int, RansacFunc> {
+class RansacIntTest : public RansacTest<int> {
   protected:
     void prepare_input(int *input, int npoints) {
         for (int i = 0; i < npoints; i++) {
@@ -343,10 +337,6 @@ class RansacIntTest : public RansacTest<int, RansacFunc> {
             input[4 * i + 3] = (int)round(ref_.at(i).y);
         }
     }
-
-    RansacFunc get_ransac_func(TransformationType type) {
-        return svt_av1_get_ransac_type(type);
-    }
 };
 
 static const TransformationType transform_table[] = {
@@ -356,7 +346,7 @@ TEST_P(RansacIntTest, CheckOutput) {
     run_test(1000);
 };
 
-INSTANTIATE_TEST_CASE_P(GlobalMotion, RansacIntTest,
-                        ::testing::ValuesIn(transform_table));
+INSTANTIATE_TEST_SUITE_P(GlobalMotion, RansacIntTest,
+                         ::testing::ValuesIn(transform_table));
 
 }  // namespace
