@@ -29,6 +29,7 @@
 #include "gtest/gtest.h"
 
 #include "definitions.h"
+#include "md_config_process.h"
 #include "transforms.h"
 #include "pcs.h"
 #include "aom_dsp_rtcd.h"
@@ -37,10 +38,6 @@
 #include "q_matrices.h"
 
 namespace QuantizeAsmTest {
-extern "C" void svt_av1_build_quantizer(
-    EbBitDepth bit_depth, int32_t y_dc_delta_q, int32_t u_dc_delta_q,
-    int32_t u_ac_delta_q, int32_t v_dc_delta_q, int32_t v_ac_delta_q,
-    Quants *const quants, Dequants *const deq);
 
 using QuantizeFunc = void (*)(const TranLow *coeff_ptr, intptr_t n_coeffs,
                               const int16_t *zbin_ptr, const int16_t *round_ptr,
@@ -87,14 +84,19 @@ class QuantizeBTest : public ::testing::TestWithParam<QuantizeParam> {
         coeff_min_ = -(1 << (7 + bd_)) + 1;
         coeff_max_ = (1 << (7 + bd_)) - 1;
         rnd_ = new SVTRandom(coeff_min_, coeff_max_);
+        PictureParentControlSet pcs;
+        pcs.scs = (SequenceControlSet *)malloc(sizeof(SequenceControlSet));
+        pcs.frm_hdr.quantization_params.base_q_idx = 0;
+        pcs.scs->static_config.sharpness = 0;
+        PictureParentControlSet *pcs_ptr = &pcs;
 
-        svt_av1_build_quantizer(bd_, 0, 0, 0, 0, 0, &qtab_quants_, &qtab_deq_);
+        svt_av1_build_quantizer(
+            pcs_ptr, bd_, 0, 0, 0, 0, 0, &qtab_quants_, &qtab_deq_);
         setup_func_ptrs();
     }
 
     virtual ~QuantizeBTest() {
         delete rnd_;
-        aom_clear_system_state();
     }
 
     void SetUp() override {
@@ -116,7 +118,6 @@ class QuantizeBTest : public ::testing::TestWithParam<QuantizeParam> {
         svt_aom_free(dqcoeff_ref_);
         svt_aom_free(qcoeff_test_);
         svt_aom_free(dqcoeff_test_);
-        aom_clear_system_state();
     }
 
     /*
@@ -339,6 +340,24 @@ INSTANTIATE_TEST_SUITE_P(
                        ::testing::Values(svt_aom_highbd_quantize_b_avx2)));
 #endif  // ARCH_X86_64
 
+#ifdef ARCH_AARCH64
+INSTANTIATE_TEST_SUITE_P(
+    LBD_NEON, QuantizeBTest,
+    ::testing::Combine(::testing::Values(static_cast<int>(TX_16X16),
+                                         static_cast<int>(TX_32X32),
+                                         static_cast<int>(TX_64X64)),
+                       ::testing::Values(static_cast<int>(EB_EIGHT_BIT)),
+                       ::testing::Values(svt_aom_quantize_b_neon)));
+
+INSTANTIATE_TEST_SUITE_P(
+    HBD_NEON, QuantizeBTest,
+    ::testing::Combine(::testing::Values(static_cast<int>(TX_16X16),
+                                         static_cast<int>(TX_32X32),
+                                         static_cast<int>(TX_64X64)),
+                       ::testing::Values(static_cast<int>(EB_TEN_BIT)),
+                       ::testing::Values(svt_aom_highbd_quantize_b_neon)));
+#endif  // ARCH_AARCH64
+
 class QuantizeBQmTest : public QuantizeBTest {
   protected:
     QuantizeBQmTest() : QuantizeBTest() {
@@ -545,13 +564,4 @@ INSTANTIATE_TEST_SUITE_P(
                        ::testing::Values(svt_av1_highbd_quantize_b_qm_avx2)));
 #endif  // ARCH_X86_64
 
-#ifdef ARCH_AARCH64
-INSTANTIATE_TEST_SUITE_P(
-    LBD_NEON, QuantizeBTest,
-    ::testing::Combine(::testing::Values(static_cast<int>(TX_16X16),
-                                         static_cast<int>(TX_32X32),
-                                         static_cast<int>(TX_64X64)),
-                       ::testing::Values(static_cast<int>(EB_EIGHT_BIT)),
-                       ::testing::Values(svt_aom_quantize_b_neon)));
-#endif  // ARCH_AARCH64
 }  // namespace QuantizeAsmTest
